@@ -196,7 +196,7 @@ class WordVectors(object):
             word, vector = parts[0], parts[1:]
             vocab.append(word)
             vectors[i] = vector
-        vocap = np.array(vocab)
+        vocab = np.array(vocab, dtype='<U200')
 
         fin.close()
         return cls(vocab=vocab, vectors=vectors, save_memory=save_memory)
